@@ -946,15 +946,12 @@ MONGOCTL_PARSER_DEF = {
             "function": "mongoctl.mongoctl.dump_command",
             "args": [
                     {
-                    "name": "dbAddress",
-                    "displayName": "DB_ADDRESS",
-                    "type" : "optional",
-                    "cmd_arg": [
-                        "--db-address"
-                    ],
+                    "name": "target",
+                    "displayName": "TARGET",
+                    "type" : "positional",
                     "nargs": 1,
-                    "help": "database addresses supported by mongoctl."
-                            " Check docs for more details."
+                    "help": "database addresse or dbpath. Check docs for"
+                            " more details."
                 },
                     {
                     "name": "username",
@@ -985,21 +982,6 @@ MONGOCTL_PARSER_DEF = {
                     ],
                     "nargs": 0
                 },
-
-                    {
-                    "name": "dbpath",
-                    "type" : "optional",
-                    "displayName": "DBPATH",
-                    "help": "directly access mongod database files in the given "
-                            "path, instead of connecting to a mongod  server -"
-                            " needs to lock the data directory, so cannot be used "
-                            "if a mongod is currently accessing the same path ",
-                    "cmd_arg": [
-                        "--dbpath"
-                    ],
-                    "nargs": 1
-                },
-
                     {
                     "name": "directoryperdb",
                     "type" : "optional",
@@ -1024,7 +1006,7 @@ MONGOCTL_PARSER_DEF = {
                     "name": "collection",
                     "type" : "optional",
                     "displayName": "COLLECTION",
-                    "help": "if dbpath specified, each db is in a separate directory",
+                    "help": "collection to use (some commands)",
                     "cmd_arg": [
                         "-c",
                         "--collection"
@@ -1096,6 +1078,159 @@ MONGOCTL_PARSER_DEF = {
             ]
         },
 
+        #### restore ####
+            {
+            "prog": "restore",
+            "group": "clientCommands",
+            "shortDescription" : "Restore MongoDB (using mongorestore0",
+            "description" : "Runs a mongorestore from specified file or directory"
+                            " to database address or dbpath. If a\n"
+                            "cluster is specified command will restore against "
+                            "the primary server.\n\n"
+                            "<db-address> can be one of:\n"
+                            "   (a) a mongodb URI (e.g. mongodb://localhost:27017[/mydb])\n"
+                            "   (b) <server-id>[/<db>]\n"
+                            "   (c) <cluster-id>[/<db>]\n",
+            "function": "mongoctl.mongoctl.restore_command",
+            "args": [
+                    {
+                    "name": "destination",
+                    "displayName": "DESTINATION",
+                    "type" : "positional",
+                    "nargs": 1,
+                    "help": "database address or dbpath. Check docs for"
+                            " more details."
+                },
+
+                    {
+                    "name": "source",
+                    "displayName": "SOURCE",
+                    "type" : "positional",
+                    "nargs": 1,
+                    "help": "directory or filename to restore from"
+                },
+                    {
+                    "name": "username",
+                    "type" : "optional",
+                    "help": "username",
+                    "cmd_arg": [
+                        "-u"
+                    ],
+                    "nargs": 1
+                },
+                    {
+                    "name": "password",
+                    "type" : "optional",
+                    "help": "password",
+                    "cmd_arg": [
+                        "-p"
+                    ],
+                    "nargs": "?"
+                },
+
+                    {
+                    "name": "verbose",
+                    "type" : "optional",
+                    "help": 'increase verbosity',
+                    "cmd_arg": [
+                        "-v",
+                        "--verbose"
+                    ],
+                    "nargs": 0
+                },
+                    {
+                    "name": "directoryperdb",
+                    "type" : "optional",
+                    "help": "if dbpath specified, each db is in a separate directory",
+                    "cmd_arg": [
+                        "--directoryperdb"
+                    ],
+                    "nargs": 0
+                },
+
+                    {
+                    "name": "journal",
+                    "type" : "optional",
+                    "help": "enable journaling",
+                    "cmd_arg": [
+                        "--journal"
+                    ],
+                    "nargs": 0
+                },
+
+                    {
+                    "name": "collection",
+                    "type" : "optional",
+                    "displayName": "COLLECTION",
+                    "help": " collection to use (some commands)",
+                    "cmd_arg": [
+                        "-c",
+                        "--collection"
+                    ],
+                    "nargs": 1
+                },
+
+
+                    {
+                    "name": "objcheck",
+                    "type" : "optional",
+                    "help": "validate object before inserting",
+                    "cmd_arg": [
+                        "--objectcheck"
+                    ],
+                    "nargs": 0
+                },
+
+                    {
+                    "name": "filter",
+                    "type" : "optional",
+                    "displayName": "FILTER",
+                    "help": "filter to apply before inserting",
+                    "cmd_arg": [
+                        "--filter"
+                    ],
+                    "nargs": 1
+                },
+
+                    {
+                    "name": "drop",
+                    "type" : "optional",
+                    "help": " drop each collection before import",
+                    "cmd_arg": [
+                        "--drop"
+                    ],
+                    "nargs": 0
+                },
+
+                    {
+                    "name": "oplogReplay",
+                    "type" : "optional",
+                    "help": "replay oplog for point-in-time restore",
+                    "cmd_arg": [
+                        "--oplogReplay"
+                    ],
+                    "nargs": 0
+                },
+
+                    {
+                    "name": "keepIndexVersion",
+                    "type" : "optional",
+                    "help": " don't upgrade indexes to newest version",
+                    "cmd_arg": [
+                        "--keepIndexVersion"
+                    ],
+                    "nargs": 0
+                },
+                    {
+                    "name": "ipv6",
+                    "type" : "optional",
+                    "cmd_arg":  "--ipv6",
+                    "nargs": 0,
+                    "help": "enable IPv6 support (disabled by default)"
+                }
+
+            ]
+        },
         #### resync-secondary ####
             {
             "prog": "resync-secondary",
@@ -1228,8 +1363,10 @@ MONGOCTL_PARSER_DEF = {
         },
 
         #### install ####
+        # TODO: Remove and replace by install-mongodb
             {
             "prog": "install",
+            "hidden": True,
             "group": "adminCommands",
             "shortDescription" : "install MongoDB",
             "description" : "install MongoDB",
@@ -1245,8 +1382,44 @@ MONGOCTL_PARSER_DEF = {
             ]
         },
         #### uninstall ####
+        # TODO: Remove and replace by uninstall-mongodb
             {
             "prog": "uninstall",
+            "hidden": True,
+            "group": "adminCommands",
+            "shortDescription" : "uninstall MongoDB",
+            "description" : "uninstall MongoDB",
+            "function": "mongoctl.mongoctl.uninstall_command",
+            "args": [
+                    {
+                    "name": "version",
+                    "type" : "positional",
+                    "nargs": 1,
+                    "displayName": "VERSION",
+                    "help": "MongoDB version to uninstall"
+                }
+            ]
+        },
+        #### install-mongodb ####
+            {
+            "prog": "install-mongodb",
+            "group": "adminCommands",
+            "shortDescription" : "install MongoDB",
+            "description" : "install MongoDB",
+            "function": "mongoctl.mongoctl.install_command",
+            "args": [
+                    {
+                    "name": "version",
+                    "type" : "positional",
+                    "nargs": "?",
+                    "displayName": "VERSION",
+                    "help": "MongoDB version to install"
+                }
+            ]
+        },
+        #### uninstall-mongodb ####
+            {
+            "prog": "uninstall-mongodb",
             "group": "adminCommands",
             "shortDescription" : "uninstall MongoDB",
             "description" : "uninstall MongoDB",
